EXPOSURE = ["unlikely", "probable", "unavoidable"]
EXPLOITATION = ["none", "PoC", "active"]
Utility = ["laborious", "complex", "efficient"]
HUMAN_IMPACT = ["low", "medium", "high", "very high"]
PRIORITY = ["defer", "scheduled", "out-of-cycle", "immediate"]
PRODUCTION = "production"
NONPRODUCTION = "non_production"
DB = "db"
STORAGE = "storage"
COMPUTE = "compute"
VERYHIGH = "very high"
HIGH = "high"
MEDIUM = "medium"
LOW = "low"
